@@ -23,10 +23,12 @@
 #include <stddef.h>
 #include <string.h>
 
-void * lsx_realloc(void * ptr, size_t newsize);
 #define lsx_malloc(size) lsx_realloc(NULL, (size))
-#define lsx_calloc(n,s) ((n)*(s)? memset(lsx_malloc((n)*(s)),0,(n)*(s)) : NULL)
+#define lsx_calloc(n,s) (((n)*(s))? memset(lsx_malloc((n)*(s)),0,(n)*(s)) : NULL)
+#define lsx_Calloc(v,n)  v = lsx_calloc(n,sizeof(*(v)))
 #define lsx_strdup(p) ((p)? strcpy((char *)lsx_malloc(strlen(p) + 1), p) : NULL)
 #define lsx_memdup(p,s) ((p)? memcpy(lsx_malloc(s), p, s) : NULL)
+#define lsx_valloc(v,n)  v = lsx_malloc((n)*sizeof(*(v)))
+#define lsx_revalloc(v,n)  v = lsx_realloc(v, (n)*sizeof(*(v)))
 
 #endif
